{% if social_networks %}
  <ul{% if social_networks_classes %} class="{{ social_networks_classes }}"{% endif %}>
    {% for social_network in social_networks %}
      <li>
        <a href="{{ social_network.get_link }}" title="{{ social_network.get_name }}" target="_blank" rel="nofollow"><i class="fa fa-{{ social_network.get_icon }}"></i></a>
      </li>
    {% endfor %}
  </ul>
{% endif %}
